<?php

if (!defined('ABSPATH')) {
    exit;
}

add_action('admin_menu', 'efcnb_add_admin_menu');
function efcnb_add_admin_menu() {
    // Add a top-level menu item at the bottom of the admin menu
    add_menu_page(
        'Easy Floating Call Now Button Settings:', // Page title
        'EFCN Button',                             // Menu title
        'manage_options',                          // Capability
        'efcnb_settings',                          // Menu slug
        'efcnb_render_settings_page',              // Callback
        'dashicons-phone',                         // Icon
        100                                        // Position near bottom
    );
}

add_action('admin_init', 'efcnb_register_settings');
function efcnb_register_settings() {
    register_setting('efcnb_settings_group', 'efcnb_settings', ['sanitize_callback' => 'efcnb_sanitize_settings']);
}

add_action('admin_post_efcnb_reset_colors', 'efcnb_reset_color_settings_handler');
function efcnb_reset_color_settings_handler() {
    check_admin_referer('efcnb_reset_colors_action');

    $options = get_option('efcnb_settings', []);
    $options['background_color'] = '#86ec6a';
    $options['inner_color'] = '#ffffff';
    $options['text_color'] = '#ffffff';
    $options['text_bg_color'] = '#000000';
    update_option('efcnb_settings', $options);

    wp_redirect(add_query_arg(['page' => 'efcnb_settings'], admin_url('admin.php')));
    exit;
}

function efcnb_sanitize_settings($input) {
    $output = [];
    $output['enabled'] = (!empty($input['enabled']) && $input['enabled'] == '1') ? '1' : '0';
    $output['phone'] = sanitize_text_field($input['phone'] ?? '');
    $output['button_text'] = sanitize_text_field($input['button_text'] ?? 'Call Us');
    $output['background_color'] = sanitize_hex_color($input['background_color'] ?? '#86ec6a') ?: '#86ec6a';
    $output['inner_color'] = sanitize_hex_color($input['inner_color'] ?? '#ffffff') ?: '#ffffff';
    $output['text_color'] = sanitize_hex_color($input['text_color'] ?? '#ffffff') ?: '#ffffff';
    $output['text_bg_color'] = sanitize_hex_color($input['text_bg_color'] ?? '#000000') ?: '#000000';
    $valid_displays = ['all', 'mobile', 'desktop'];
    $display = $input['display'] ?? 'all';
    $output['display'] = in_array($display, $valid_displays) ? $display : 'all';
    $pages = isset($input['pages']) && is_array($input['pages']) ? array_map('sanitize_text_field', $input['pages']) : [];
    $valid_pages = ['home', 'posts', 'pages', 'categories'];
    $output['pages'] = array_intersect($pages, $valid_pages);
    return $output;
}

function efcnb_render_settings_page() {
    $options = get_option('efcnb_settings');
    ?>
    <div class="wrap">
        <h1>Easy Floating Call Now Button Settings:</h1>
        <form method="post" action="options.php">
            <?php settings_fields('efcnb_settings_group'); ?>
            <table class="form-table">
                <tr>
                    <th>Enable Button</th>
                    <td><input type="checkbox" name="efcnb_settings[enabled]" value="1" <?php checked($options['enabled'], '1'); ?>></td>
                </tr>
                <tr>
                    <th>Phone Number</th>
                    <td><input type="text" name="efcnb_settings[phone]" value="<?php echo esc_attr($options['phone'] ?? ''); ?>" class="regular-text"></td>
                </tr>
                <tr>
                    <th>Button Text</th>
                    <td><input type="text" name="efcnb_settings[button_text]" value="<?php echo esc_attr($options['button_text'] ?? 'Call Us'); ?>" class="regular-text"></td>
                </tr>
                <tr>
                    <th>Button Background Color</th>
                    <td><input type="color" name="efcnb_settings[background_color]" value="<?php echo esc_attr($options['background_color'] ?? '#86ec6a'); ?>"></td>
                </tr>
                <tr>
                    <th>Inner Element Color</th>
                    <td><input type="color" name="efcnb_settings[inner_color]" value="<?php echo esc_attr($options['inner_color'] ?? '#ffffff'); ?>"></td>
                </tr>
                <tr>
                    <th>Text Color</th>
                    <td><input type="color" name="efcnb_settings[text_color]" value="<?php echo esc_attr($options['text_color'] ?? '#ffffff'); ?>"></td>
                </tr>
                <tr>
                    <th>Text Background Color</th>
                    <td>
                        <input type="color" name="efcnb_settings[text_bg_color]" value="<?php echo esc_attr($options['text_bg_color'] ?? '#000000'); ?>">
                        <br><br>
                        <a class="button button-secondary" href="<?php echo esc_url(wp_nonce_url(admin_url('admin-post.php?action=efcnb_reset_colors'), 'efcnb_reset_colors_action')); ?>">Reset to Default Colors</a>
                    </td>
                </tr>
                <tr>
                    <th>Devices</th>
                    <td>
                        <select name="efcnb_settings[display]">
                            <option value="all" <?php selected($options['display'], 'all'); ?>>All Devices</option>
                            <option value="mobile" <?php selected($options['display'], 'mobile'); ?>>Mobile Only</option>
                            <option value="desktop" <?php selected($options['display'], 'desktop'); ?>>Desktop Only</option>
                        </select>
                    </td>
                </tr>
                <tr>
                    <th>Pages to Display</th>
                    <td>
                        <label><input type="checkbox" name="efcnb_settings[pages][]" value="home" <?php checked(in_array('home', $options['pages'] ?? [])); ?>> Home</label><br>
                        <label><input type="checkbox" name="efcnb_settings[pages][]" value="posts" <?php checked(in_array('posts', $options['pages'] ?? [])); ?>> Posts</label><br>
                        <label><input type="checkbox" name="efcnb_settings[pages][]" value="pages" <?php checked(in_array('pages', $options['pages'] ?? [])); ?>> Pages</label><br>
                        <label><input type="checkbox" name="efcnb_settings[pages][]" value="categories" <?php checked(in_array('categories', $options['pages'] ?? [])); ?>> Categories</label><br>
                    </td>
                </tr>
            </table>
            <?php submit_button(); ?>
        </form>
    </div>
    <?php
}